## You know you’ve been thinking about serving a gay muscle stud like me.

I am the Alpha Male that makes you so weak you can’t do anything but submit to my needs. Your an inferior little bottom boy who wants to please a real man like me.

Whether it’s my ripped body, hot meat or my tight virgin ass. Most likely you can’t say the same for your hole, can you?

## Kneel Before the Gay Muscle Stud

You’d cough your holes up to me in a heart beat so don’t fool yourself. It boils down to this; I am the Master and you are a slave. So take your place and kneel in the presence of a real gay muscle stud. Always up for anything so you bring it on and see if you can shock me; it’s impossible.

If you are not lucky enough to find me when I am online, you can always get used by one of my fellow gay muscle hunks.

### Leave a Reply Cancel reply

Your email address will not be published. Required fields are marked *

Comment *

Name *

Email *

Website